#!/bin/bash
# packager           : Fred. Galusik <fredg> (fred~AT~zenwalk.fr)
# source location    : http://reiserfs.osdn.org.ua
# last revised       : 13.02.2008

softname='progsreiserfs'
softversion='0.3.0.4'
packageversion='52.1'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
     |-----handy-ruler------------------------------------------------------|
progsreiserfs: Progsreiserfs - A set of utilities for Reiserfs FS
progsreiserfs:
progsreiserfs: This is a library for reiserfs filesystem access and manipulation.
progsreiserfs: The primary goal is to develop the nice, full functionality library
progsreiserfs: which might be linked against any projects which needed reiserfs
progsreiserfs: filesystem access. There are GNU Parted, GNU GRUB, Yaboot,
progsreiserfs: Partimage, EVMS, etc. The second goal is high maintainability
progsreiserfs: source code. The third goal is to develop an alternative set of
progsreiserfs: the reiserfsprogs as small and nice frontends to this library.
progsreiserfs:
progsreiserfs:
EOF

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=/usr \
      --libdir=/usr/lib \
      --disable-debug \
      --enable-shared=no \
      --program-prefix="" \
      --program-suffix="" \
      --build=$arch-slackware-linux

    make
    make install DESTDIR=$dest

# add 'default' files
    cp -a \
      ABOUT-NLS AUTHORS BUGS ChangeLog COPYING INSTALL NEWS README THANKS TODO \
      $dest/usr/doc/$softname-$softversion
      
# Compress Man Pages
gzip -9 $dest/usr/man/man?/*

# Strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.tgz

# md5sum signature
cd $buildir
md5sum $package.tgz > $package.md5

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
